Routing
=======

.. toctree::
    :maxdepth: 3

    grp_routing_actions
    grp_routing_routers
    grp_routing_modifiers
    grp_routing_subjects
    grp_routing_vars


.. automodule:: uwsgiconf.options.routing
   :members:

